Here is the bulk of the sanitizing.
Almost all occurrences of "bytecode" in the sources have been eliminated.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@37913 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/ExecutionEngine/JIT/JIT.cpp b/lib/ExecutionEngine/JIT/JIT.cpp
index cb698c3..603f8ec 100644
--- a/lib/ExecutionEngine/JIT/JIT.cpp
+++ b/lib/ExecutionEngine/JIT/JIT.cpp
@@ -8,7 +8,7 @@
 //===----------------------------------------------------------------------===//
 //
 // This tool implements a just-in-time compiler for LLVM, allowing direct
 // execution of LLVM bytecode in an efficient manner.
 //
 //===----------------------------------------------------------------------===//
 
@@ -258,7 +258,7 @@
     return Addr;   // Check if function already code gen'd
 
   // Make sure we read in the function if it exists in this Module.
-  if (F->hasNotBeenReadFromBytecode()) {
+  if (F->hasNotBeenReadFromBitcode()) {
     // Determine the module provider this function is provided by.
     Module *M = F->getParent();
     ModuleProvider *MP = 0;
@@ -273,7 +273,7 @@
     std::string ErrorMsg;
     if (MP->materializeFunction(F, &ErrorMsg)) {
       cerr << "Error reading function '" << F->getName()
-           << "' from bytecode file: " << ErrorMsg << "\n";
+           << "' from bitcode file: " << ErrorMsg << "\n";
       abort();
     }
   }
@@ -8,7 +8,7 @@
 //
 // This tool implements a just-in-time compiler for LLVM, allowing direct
-// execution of LLVM bytecode in an efficient manner.
+// execution of LLVM bitcode in an efficient manner.
 //
 //===----------------------------------------------------------------------===//